@@ -25,16 +25,6 @@
 
 #ifndef FILTER_PARSER_HPP
 #define FILTER_PARSER_HPP
-// stl
-#include <stack>
-#include <iostream>
-// boost
-#include <boost/shared_ptr.hpp>
-#include <boost/spirit/core.hpp>
-#include <boost/spirit/symbols.hpp>
-#include <boost/spirit/utility/confix.hpp>
-#include <boost/spirit/utility/escape_char.hpp>
-#include <boost/spirit/utility/chset.hpp> 
 // mapnik
 #include <mapnik/value.hpp>
 #include <mapnik/comparison.hpp>
@@ -44,6 +34,19 @@
 #include <mapnik/regex_filter.hpp>
 #include <mapnik/logical.hpp>
 
+// boost
+//#define BOOST_SPIRIT_DEBUG
+#include <boost/shared_ptr.hpp>
+#include <boost/spirit/core.hpp>
+#include <boost/spirit/symbols.hpp>
+#include <boost/spirit/utility/confix.hpp>
+#include <boost/spirit/utility/escape_char.hpp>
+#include <boost/spirit/utility/chset.hpp> 
+
+// stl
+#include <stack>
+#include <iostream>
+
 using namespace boost::spirit;
 using boost::shared_ptr;
 
@@ -417,7 +420,26 @@ namespace mapnik
 
                 or_expr  = and_expr >> *(L"or" >> and_expr)[compose_or_filter<FeatureT>(self.filters)];
 
-                filter_statement = or_expr;	
+                filter_statement = or_expr >> *(space_p) >> end_p;	
+
+#ifdef BOOST_SPIRIT_DEBUG
+                BOOST_SPIRIT_DEBUG_RULE( factor ); 
+                BOOST_SPIRIT_DEBUG_RULE( term );
+                BOOST_SPIRIT_DEBUG_RULE( expression );
+                BOOST_SPIRIT_DEBUG_RULE( relation );
+                BOOST_SPIRIT_DEBUG_RULE( equation );
+                BOOST_SPIRIT_DEBUG_RULE( not_expr );
+                BOOST_SPIRIT_DEBUG_RULE( and_expr );
+                BOOST_SPIRIT_DEBUG_RULE( or_expr );
+
+                BOOST_SPIRIT_DEBUG_RULE( filter_statement );   
+                BOOST_SPIRIT_DEBUG_RULE( literal );
+                BOOST_SPIRIT_DEBUG_RULE( number );
+                BOOST_SPIRIT_DEBUG_RULE( string_ );
+                BOOST_SPIRIT_DEBUG_RULE( property );
+                BOOST_SPIRIT_DEBUG_RULE( function );
+                BOOST_SPIRIT_DEBUG_RULE( regex );
+#endif
             }
 	    
             boost::spirit::rule<ScannerT> const& start() const
@@ -444,6 +466,8 @@ namespace mapnik
             symbols<string> func1_op;
             symbols<string> func2_op;
             symbols<string> spatial_op;
+
+
         };
         stack<shared_ptr<filter<FeatureT> > >& filters;
         stack<shared_ptr<expression<FeatureT> > >& exprs;
