@@ -24,12 +24,16 @@
 #ifndef MAP_LOADER_HPP
 #define MAP_LOADER_HPP
 
-#include <string>
+#ifdef HAVE_CONFIG_H
+  #include <config.h>
+#endif
+
 #include <mapnik/map.hpp>
+#include <string>
 
 namespace mapnik
 {
-    MAPNIK_DECL void load_map(Map & map, std::string const& filename);
+    MAPNIK_DECL void load_map(Map & map, std::string const& filename, bool strict = false);
 }
 
 #endif // LOAD_MAP_HPP
